# vi: ts=4 expandtab
#
# Copyright (C) 2014 Canonical Ltd.
#
# Author: Blake Rouse <blake.rouse@canonical.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3, as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from __future__ import (
    absolute_import,
    print_function,
    unicode_literals,
    )

import sys

from argparse import ArgumentParser
from builder.osystems import OperatingSystemRegistry


def load_parser():
    """Load command line parser including the submodule parsers."""
    parser = ArgumentParser(
        description="Image builder for the Curtin installer.")
    parser.add_argument(
        '--vcpus',
        default="1", help="Number of vcpus to configure for the installation.")
    parser.add_argument(
        '-r', '--ram',
        default=2048, type=int, help="Memory to allocate for installation.")
    parser.add_argument(
        '-i', '--interface',
        default='virbr0', help="Bridge interface for created virtual machine.")
    parser.add_argument(
        '-o', '--output',
        default='build-output',
        help="Output directory of built image.")
    parser.add_argument(
        '--install-deps',
        action='store_true', help="Install dependencies for curtin-img-builder.")

    # Check if install-deps is already in sys.argv. If it is then do not add
    # the positional arguments. Note: there probably is a better way to do this,
    # but it works for now.
    if '--install-deps' in sys.argv:
        return parser

    # Get names, arches, and extra parser arguments
    names = []
    arches = set()
    for name, osystem in OperatingSystemRegistry:
        names.append(name)
        arches = arches.union(osystem.arches)
        osystem.build_parser(parser)

    # Positional arguments
    parser.add_argument(
        'osystem',
        choices=names, help="Operating system to build.")
    parser.add_argument(
        'arch',
        choices=arches,
        help="Architecture to build.")
    return parser
